@@ -21,8 +21,8 @@ class DuplicationError(BaseException):
     pass
 
 
-class NoHookCommandDuplicationError(BaseException):
-    """フックを必要としないオプション（コマンド）が複数あった場合発生"""
+class NoHookOptionDuplicationError(BaseException):
+    """フックを必要としないオプション(デフォルトオプション)が複数あった場合発生"""
     pass
 
 
@@ -57,9 +57,9 @@ class MinimumParser:
         if hooks == None:
 
             if self.is_exist_no_hook_option == True:
-                raise NoHookCommandDuplicationError("The Command that don't need hook already exist.")
+                raise NoHookOptionDuplicationError("The Deafault option that don't need hook already exist.")
 
-            command_obj = Command(description, argcount,
+            command_obj = DefaultOption(description, argcount,
                                   argument_names, arg_types, func)
             self.no_hook_command = command_obj
             self.is_exist_no_hook_option = True
@@ -99,7 +99,7 @@ class MinimumParser:
 
         return function_wrapper
 
-    def command(self, **kwargs):
+    def default(self, **kwargs):
         """フックを使わないオプションを定義したい場合に使うデコレータ"""
 
         # get description
@@ -131,23 +131,40 @@ class MinimumParser:
         if self.app_version:
             self.__add_version_opt()
 
-        if len(target) < 2:
+        if self.is_exist_no_hook_option == True:
 
-            if self.is_exist_no_hook_option == True:
+            if len(target) < 2:
+                # no argument default option
+                self.no_hook_command.run()
+                return
 
-                option_arguments_values = target[2:]
+            elif len(target) >= 2:
+                option_arguments_values = target[1:]
                 option_arguments = dict(
                     zip(self.no_hook_command.func_args, option_arguments_values))
 
-                if len(option_arguments) != 0:
+                # 指定された引数がDefaultOptionのものなのか、定義済のOptionのHookなのかを判定
+                is_default_option_arg = None
+                hooks = [i.hooks for i in self.options]
+
+                for hook in hooks:
+                    for value in option_arguments_values:
+                        if value not in hook:
+                            # 定義済OptionのHookには含まれていないのでDefaultOptionの引数
+                            is_default_option_arg = True
+                        else:
+                            is_default_option_arg = False
+                            break
+
+                    if is_default_option_arg == False:
+                        break
+
+                if is_default_option_arg == True:
                     self.no_hook_command.run(option_arguments)
-                else:
-                    self.no_hook_command.run()
-
-                return
-
-            else:
-
+                    return 
+                    
+        else:
+            if len(target) < 2:
                 self.call_usage(self.prog_name)
                 kill(1)
 
@@ -368,8 +385,8 @@ class Option(object):
             return self.__repr__()
 
 
-class Command(object):
-    """フックを必要としないオプション（コマンド）を定義
+class DefaultOption(object):
+    """フックを必要としないオプション（デフォルトオプション）を定義
         option_desc         - オプションの説明
         func_argcount       - オプションがフックされたら起動する関数の引数の数
         func_args           - オプションがフックされたら起動する関数の引数の名前のタプル
@@ -438,7 +455,7 @@ class Command(object):
         return kwargs
 
     def __repr__(self):
-        return ("Command(description='%s', " +
+        return ("DeafultOption(description='%s', " +
                 "func_argcount=%d, func_args=(%s), func=%s)") % (
                     self.description,
                     self.func_argcount,
